"""
   An implementation of high-level API to SNMP v.1 message objects (RFC1157)

   Copyright 1999-2003 by Ilya Etingof <ilya@glas.net>. See LICENSE for
   details.
"""
# Module public names
__all__ = [ 'GetRequestMixIn', 'GetNextRequestMixIn', 'SetRequestMixIn',
            'GetResponseMixIn', 'ResponseMixIn', 'TrapMixIn',
            'registerMixIns' ]

from pysnmp.proto import v1
from pysnmp.proto.api import error

class MessageMixIn:
    def apiGenGetVersion(self): return self['version'].get()
    apiGetVersion = apiGenGetVersion
    def apiGenGetCommunity(self): return self['community'].get()
    apiGetCommunity = apiGenGetCommunity
    def apiGenSetCommunity(self, value): self['community'].set(value)
    apiSetCommunity = apiGenSetCommunity
    def apiGenGetPdu(self): return self['pdu'].values()[0]
    apiGetPdu = apiGenGetPdu
    def apiGenSetPdu(self, value): self['pdu'][None] = value
    apiSetPdu = apiGenSetPdu

# Request message mix-ins
class RequestMixIn(MessageMixIn): pass
class GetRequestMixIn(MessageMixIn): pass
class GetNextRequestMixIn(MessageMixIn): pass
class SetRequestMixIn(MessageMixIn): pass
class GetResponseMixIn(MessageMixIn): pass
# A v2c-style alias
ResponseMixIn = GetResponseMixIn
class TrapMixIn(MessageMixIn): pass

def mixIn():
    """Register this module's mix-in classes at their bases
    """
    mixInComps = [ (v1.Request, RequestMixIn),
                   (v1.GetRequest, GetRequestMixIn),
                   (v1.GetNextRequest, GetNextRequestMixIn),
                   (v1.SetRequest, SetRequestMixIn),
                   (v1.GetResponse, GetResponseMixIn),
                   (v1.Trap, TrapMixIn) ]
    
    for (baseClass, mixIn) in mixInComps:
        if mixIn not in baseClass.__bases__:
            baseClass.__bases__ = baseClass.__bases__ + (mixIn, )
