"""
   An implementation of high-level API to SNMP v.2c message objects (RFC1905)

   Copyright 1999-2003 by Ilya Etingof <ilya@glas.net>. See LICENSE for
   details.
"""
# Module public names
__all__ = [ 'GetRequestMixIn', 'GetNextRequestMixIn', 'SetRequestMixIn',
            'ResponseMixIn', 'GetBulkRequestMixIn', 'InformRequestMixIn',
            'ReportMixIn', 'SnmpV2TrapMixIn', 'registerMixIns' ]

from pysnmp.proto import v2c
from pysnmp.proto.api.generic import v1
from pysnmp.proto.api import error

class MessageMixIn(v1.MessageMixIn): pass

class RequestMixIn(MessageMixIn): pass
class GetRequestMixIn(MessageMixIn): pass
class GetNextRequestMixIn(MessageMixIn): pass
class SetRequestMixIn(MessageMixIn): pass
class InformRequestMixIn(MessageMixIn): pass
class SnmpV2TrapMixIn(MessageMixIn): pass
# A v1-style alias
TrapMixIn = SnmpV2TrapMixIn
class ReportMixIn(MessageMixIn): pass
class GetBulkRequestMixIn(MessageMixIn): pass
class ResponseMixIn(MessageMixIn): pass
# A v1-style alias
GetResponseMixIn = ResponseMixIn

def mixIn():
    """Register this module's mix-in classes at their bases
    """
    mixInComps = [ (v2c.Request, RequestMixIn),
                   (v2c.GetRequest, GetRequestMixIn),
                   (v2c.GetNextRequest, GetNextRequestMixIn),
                   (v2c.SetRequest, SetRequestMixIn),
                   (v2c.InformRequest, InformRequestMixIn),
                   (v2c.SnmpV2Trap, SnmpV2TrapMixIn),
                   (v2c.Report, ReportMixIn),
                   (v2c.GetBulkRequest, GetBulkRequestMixIn),
                   (v2c.Response, ResponseMixIn) ]

    for (baseClass, mixIn) in mixInComps:
        if mixIn not in baseClass.__bases__:
            baseClass.__bases__ = baseClass.__bases__ + (mixIn, )
