"""
   UCD-SNMP-style command line interface to SNMP v.1 messages (RFC1157)

   Copyright 1999-2003 by Ilya Etingof <ilya@glas.net>. See LICENSE for
   details.
"""
# Module public names
__all__ = [ 'GetRequestMixIn', 'GetNextRequestMixIn', 'SetRequestMixIn',
            'TrapMixIn', 'registerMixIns' ]

from pysnmp.proto import v1
from pysnmp.proto.cli import error

class MessageMixIn:
    def cliUcdGetUsage(self):
        return '<community> ' + self['pdu'].values()[0].cliUcdGetUsage()
    cliGetUsage = cliUcdGetUsage
    
    def cliUcdSetArgs(self, args):
        """Parse C/L args into message components
        """
        if len(args) < 1:
            raise error.BadArgumentError('Missing community name')
        self.apiGenSetCommunity(args[0])
        return self['pdu'].values()[0].cliUcdSetArgs(args[1:])
    cliSetArgs = cliUcdSetArgs

class GetRequestMixIn(MessageMixIn): pass
class GetNextRequestMixIn(MessageMixIn): pass
class SetRequestMixIn(MessageMixIn): pass
class TrapMixIn(MessageMixIn): pass

def mixIn():
    """Register this module's mix-in classes at their bases
    """
    mixInComps = [ (v1.GetRequest, GetRequestMixIn),
                   (v1.GetNextRequest, GetNextRequestMixIn),
                   (v1.SetRequest, SetRequestMixIn),
                   (v1.Trap, TrapMixIn) ]

    for (baseClass, mixIn) in mixInComps:
        if mixIn not in baseClass.__bases__:
            baseClass.__bases__ = baseClass.__bases__ + (mixIn, )
